Installation
============

The most recent release can be installed from
`PyPI <https://pypi.org/project/pyBiodatafuse>`_ with:

.. code-block:: shell

    $ pip install pyBiodatafuse

The most recent code and data can be installed directly from GitHub with:

.. code-block:: shell

    $ pip install git+https://github.com/BioDataFuse/pyBiodatafuse.git

To install in development mode, use the following:

.. code-block:: shell

    $ git clone git+https://github.com/BioDataFuse/pyBiodatafuse.git
    $ cd pyBiodatafuse
    $ pip install -e .
